@@ -68,7 +68,7 @@ void CatalogImportPlugin::setHeader(const CatalogItem& item)
     d->_updateHeader = true;
 }
 
-void CatalogImportPlugin::setCodec(QTextCodec* codec)
+void CatalogImportPlugin::setCodec(const QByteArray &codec)
 {
     d->_codec = codec;
 }
@@ -118,7 +118,6 @@ void CatalogImportPlugin::commitTransaction()
     //if( d->_updateErrorList ) d->_catalog->setErrorIndex(d->_errorList);
 
     catalog->m_maxLineLength = _maxLineLength;
-    catalog->m_trailingNewLines = _trailingNewLines;
 }
 
 }
