@@ -28,22 +28,22 @@ QString enhanceLangCode(const QString& langCode)
 
 #ifdef HAVE_HUNSPELL
 #include <hunspell.hxx>
-#include <QTextCodec>
+#include <QStringConverter>
 
 struct SpellerAndCodec {
     Hunspell* speller{nullptr};
-    QTextCodec* codec{nullptr};
-    SpellerAndCodec(): speller(nullptr), codec(nullptr) {}
+    QByteArray codec;
+    SpellerAndCodec(): speller(nullptr) {}
     explicit SpellerAndCodec(const QString& langCode);
 };
 
 SpellerAndCodec::SpellerAndCodec(const QString& langCode)
 {
 #ifdef Q_OS_MAC
-    QString dictPath = QStringLiteral("/Applications/LibreOffice.app/Contents/Resources/extensions/dict-") + langCode.leftRef(2) + QLatin1Char('/');
+    QString dictPath = QStringLiteral("/Applications/LibreOffice.app/Contents/Resources/extensions/dict-") + QStringView(langCode).left(2) + QLatin1Char('/');
     if (langCode == QLatin1String("pl_PL")) dictPath = QStringLiteral("/System/Library/Spelling/");
 #elif defined(Q_OS_WIN)
-    QString dictPath = QStringLiteral("C:/Program Files (x86)/LibreOffice 5/share/extensions/dict-") + langCode.leftRef(2) + QLatin1Char('/');
+    QString dictPath = QStringLiteral("C:/Program Files (x86)/LibreOffice 5/share/extensions/dict-") + QStringView(langCode).left(2) + QLatin1Char('/');
 #else
     QString dictPath = QStringLiteral("/usr/share/hunspell/");
     if (!QFileInfo::exists(dictPath))
@@ -55,9 +55,7 @@ SpellerAndCodec::SpellerAndCodec(const QString& langCode)
         dic = dictPath + enhanceLangCode(langCode) + QLatin1String(".dic");
     if (QFileInfo::exists(dic)) {
         speller = new Hunspell(QString(dictPath + langCode + QLatin1String(".aff")).toLatin1().constData(), dic.toLatin1().constData());
-        codec = QTextCodec::codecForName(speller->get_dic_encoding());
-        if (!codec)
-            codec = QTextCodec::codecForLocale();
+        codec = QStringDecoder(speller->get_dic_encoding()).isValid() ? speller->get_dic_encoding() : "UTF-8";
     }
 }
 
@@ -82,11 +80,14 @@ QString stem(const QString& langCode, const QString& word)
     if (!speller)
         return word;
 
-    const std::vector<std::string> result1 = speller->analyze(sc.codec->fromUnicode(word).toStdString());
+    QStringEncoder encoder(sc.codec.constData());
+    const std::vector<std::string> result1 = speller->analyze(QByteArray(encoder.encode(word)).toStdString());
     const std::vector<std::string> result2 = speller->stem(result1);
 
-    if (!result2.empty())
-        result = sc.codec->toUnicode(QByteArray::fromStdString(result2[0]));
+    if (!result2.empty()) {
+        QStringDecoder decoder(sc.codec.constData());
+        result = decoder.decode(QByteArray::fromStdString(result2[0]));
+    }
 #endif
 
     return result;
@@ -95,7 +96,7 @@ QString stem(const QString& langCode, const QString& word)
 void cleanupSpellers()
 {
 #ifdef HAVE_HUNSPELL
-    for (const SpellerAndCodec& sc : qAsConst(hunspellers))
+    for (const SpellerAndCodec& sc : std::as_const(hunspellers))
         delete sc.speller;
 
 #endif
