@@ -35,7 +35,6 @@ MergeView::MergeView(QWidget* parent, Catalog* catalog, bool primary)
                   i18nc("@title:window that displays difference between current file and 'merge source'", "Primary Sync") :
                   i18nc("@title:window that displays difference between current file and 'merge source'", "Secondary Sync"))
     , m_hasInfoTitle(m_normTitle + QLatin1String(" [*]"))
-    , m_primary(primary)
 {
     setObjectName(primary ? QStringLiteral("mergeView-primary") : QStringLiteral("mergeView-secondary"));
     setWidget(m_browser);
@@ -172,7 +171,7 @@ void MergeView::mergeOpen(QString mergeFilePath)
         //for AutoSync
 
         QString path = mergeFilePath;
-        QString oldPath = path;
+        const QString oldPath = path;
         path.replace(Project::instance()->poDir(), Project::instance()->branchDir());
 
         if (oldPath == path) { //if file doesn't exist both are empty
@@ -209,7 +208,7 @@ void MergeView::mergeOpen(QString mergeFilePath)
             saidMergeFilePath.clear();
     }
 
-    int errorLine = m_mergeCatalog->loadFromUrl(mergeFilePath, saidMergeFilePath);
+    const int errorLine = m_mergeCatalog->loadFromUrl(mergeFilePath, saidMergeFilePath);
     if (Q_LIKELY(errorLine == 0)) {
         if (m_pos.entry > 0)
             Q_EMIT signalPriorChangedAvailable(m_pos.entry > m_mergeCatalog->firstChangedIndex());
@@ -242,7 +241,7 @@ int MergeView::pluralFormsAvailableForward()
     if (Q_LIKELY(m_pos.entry == -1 || !m_mergeCatalog->isPlural(m_pos.entry)))
         return -1;
 
-    int formLimit = qMin(m_baseCatalog->numberOfPluralForms(), m_mergeCatalog->numberOfPluralForms()); //just sanity check
+    const int formLimit = qMin(m_baseCatalog->numberOfPluralForms(), m_mergeCatalog->numberOfPluralForms()); //just sanity check
     DocPosition pos = m_pos;
     while (++(pos.form) < formLimit) {
         if (m_baseCatalog->msgstr(pos) != m_mergeCatalog->msgstr(pos))
@@ -272,7 +271,7 @@ void MergeView::gotoPrevChanged()
     DocPosition pos;
 
     //first, check if there any plural forms waiting to be synced
-    int form = pluralFormsAvailableBackward();
+    const int form = pluralFormsAvailableBackward();
     if (Q_UNLIKELY(form != -1)) {
         pos = m_pos;
         pos.form = form;
@@ -298,7 +297,7 @@ void MergeView::gotoNextChanged(bool approvedOnly)
     DocPosition pos = m_pos;
 
     //first, check if there any plural forms waiting to be synced
-    int form = pluralFormsAvailableForward();
+    const int form = pluralFormsAvailableForward();
     if (Q_UNLIKELY(form != -1)) {
         pos = m_pos;
         pos.form = form;
@@ -315,8 +314,11 @@ void MergeView::gotoNextChanged(bool approvedOnly)
 
 void MergeView::mergeBack()
 {
-    if (m_pos.entry == -1 || !m_mergeCatalog || m_baseCatalog->msgstr(m_pos).isEmpty())
+    if (m_pos.entry == -1
+        || m_mergeCatalog == nullptr
+        || (m_baseCatalog != nullptr && m_baseCatalog->msgstr(m_pos).isEmpty())) {
         return;
+    }
 
     m_mergeCatalog->copyFromBaseCatalog(m_pos);
 }
@@ -324,10 +326,10 @@ void MergeView::mergeBack()
 void MergeView::mergeAccept()
 {
     if (m_pos.entry == -1
-        || !m_mergeCatalog
-        //||m_baseCatalog->msgstr(m_pos)==m_mergeCatalog->msgstr(m_pos)
-        || m_mergeCatalog->msgstr(m_pos).isEmpty())
+        || m_mergeCatalog == nullptr
+        || m_mergeCatalog->msgstr(m_pos).isEmpty()) {
         return;
+    }
 
     m_mergeCatalog->copyToBaseCatalog(m_pos);
 
@@ -338,9 +340,9 @@ void MergeView::mergeAcceptAllForEmpty()
 {
     if (Q_UNLIKELY(!m_mergeCatalog)) return;
 
-    bool containsBefore = std::find(m_mergeCatalog->differentEntries().begin(), m_mergeCatalog->differentEntries().end(), m_pos.entry) != m_mergeCatalog->differentEntries().end();
+    const bool containsBefore = std::find(m_mergeCatalog->differentEntries().begin(), m_mergeCatalog->differentEntries().end(), m_pos.entry) != m_mergeCatalog->differentEntries().end();
     m_mergeCatalog->copyToBaseCatalog(/*MergeCatalog::EmptyOnly*/MergeCatalog::HigherOnly);
-    bool containsAfter = std::find(m_mergeCatalog->differentEntries().begin(), m_mergeCatalog->differentEntries().end(), m_pos.entry) != m_mergeCatalog->differentEntries().end();
+    const bool containsAfter = std::find(m_mergeCatalog->differentEntries().begin(), m_mergeCatalog->differentEntries().end(), m_pos.entry) != m_mergeCatalog->differentEntries().end();
     if (containsBefore != containsAfter)
         Q_EMIT gotoEntry(m_pos, 0);
 }
@@ -348,7 +350,7 @@ void MergeView::mergeAcceptAllForEmpty()
 
 bool MergeView::event(QEvent *event)
 {
-    if (event->type() == QEvent::ToolTip && m_mergeCatalog) {
+    if ((event->type() == QEvent::ToolTip) && m_mergeCatalog) {
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
         QString text = QStringLiteral("<b>") + QDir::toNativeSeparators(filePath()) + QStringLiteral("</b>\n") + i18nc("@info:tooltip", "Different entries: %1\nUnmatched entries: %2",
                        m_mergeCatalog->differentEntries().size(), m_mergeCatalog->unmatchedCount());
